@@ -1,8 +1,284 @@
 
+# Special Functions for PDF and RTF ---------------------------------------
+
+
+#' @title
+#' Create a text report, but not on the file system
+#'
+#' @description
+#' This function creates a report, using the
+#' parameters provided in the report_spec object.
+#'
+#' @param x The report_spec object to write.
+#' @return The report spec.
+#' @noRd
+create_report_text <- function(rs) {
+  
+  # Calculate available space for content 
+  rs <- page_setup(rs)
+  
+  # Get page template for easy access
+  pt <- rs$page_template
+  
+  # Put content in new variable for easy access
+  ls <- rs$content
+  
+  # Break content into pages
+  ret <- paginate_content(rs, ls)
+  
+  # Assign table column widths back to report spec for reference
+  rs$column_widths <- ret[["widths"]]
+  
+  # Assign graphics flag back to report spec
+  rs$has_graphics <- ret[["has_graphics"]]
+  
+  # Assign pages to ls and continue processing
+  ls <- ret[["pages"]]
+  
+  # Deal with preview
+  if (!is.null(rs$preview)) {
+    if (rs$preview < length(ls[[1]]$pages))
+      ls[[1]]$pages <- ls[[1]]$pages[seq(1, rs$preview)]
+  }
+  
+  # Combine all content pages 
+  res <- create_content(rs, ls, pt)
+  rs <- res$rs
+  ls <- res$ls
+  
+  # After report is created, fix the page numbers.
+  # Reason is we don't really know how many pages there are 
+  # until the report is created.
+  upt <- update_page_numbers(rs, ls)
+  
+  res <- list(rs = rs, ls = upt)
+  
+  return(res)
+}
+
+
+#' @title Create content for PDF and RTF output type.
+#' @description This loop prepares pages created in paginate_content
+#' @noRd
+create_content <- function(rs, ls, pt) {
+  
+  ret <- list()
+
+  counter <- 0
+  page <- 0
+  last_object <- FALSE
+  last_page <- FALSE
+  page_open <- FALSE
+  
+  blank_margin_top <- rep("", rs$blank_margin_top)
+  blank_margin_left <- paste0(rep(" ", rs$blank_margin_left), collapse = "")
+  
+  
+  for (cont in ls) {
+    
+    
+    # Increment counter
+    counter <- counter + 1
+    page <- 0
+    
+    
+    # Set last_object flag
+    if (counter == length(ls))
+      last_object <- TRUE
+    else 
+      last_object <- FALSE
+    
+    
+    for (pg in cont$pages) {
+    
+      page <- page + 1
+      
+      # Vector to hold lines on a page
+      if (page_open == FALSE)
+        lns <- c()
+      
+      if (page == length(cont$pages))
+        last_page <- TRUE
+      else
+        last_page <- FALSE
+      
+      
+      
+      if (rs$blank_margins)
+        lns <- append(lns, blank_margin_top)
+      
+      
+      #print(page_open)
+      if (page_open == FALSE) {
+        if (!is.null(pt$page_header))
+          lns <- append(lns, paste0(blank_margin_left, pt$page_header))
+        
+        if (!is.null(pt$title_hdr))
+          lns <- append(lns, paste0(blank_margin_left, 
+                                     trimws(pt$title_hdr, which = "right")))
+        
+        if (!is.null(pt$titles))
+          lns <- append(lns, paste0(blank_margin_left, 
+                                     trimws(pt$titles, which = "right")))
+        
+      }
+      
+      if (!is.null(pg)) {
+        tmp <- trimws(pad_any(pg, rs$line_size, get_justify(cont$align)), 
+                      which = "right")
+        lns <- append(lns, paste0(blank_margin_left, tmp))
+        
+      }
+      
+      # Set page_open flag based on status of page_break and current objects
+      if (last_object == FALSE & last_page == TRUE & cont$page_break == FALSE)
+        page_open <- TRUE
+      else 
+        page_open <- FALSE
+      
+      if (page_open == FALSE) {
+        
+        if (!is.null(pt$footnotes))
+          lns <- append(lns, paste0(blank_margin_left,
+                                     trimws(pt$footnotes, which = "right")))
+        
+        if (!is.null(pt$page_footer))
+          lns <- append(lns, paste0(blank_margin_left, pt$page_footer))
+        
+        # Increment total page count
+        if (is.null(rs$pages))
+          rs$pages <- 1
+        else 
+          rs$pages <- rs$pages + 1 
+        
+        # If page not open, add to list
+        ret[[length(ret) + 1]] <- lns 
+        
+        
+      }
+  
+      
+    }
+    
+  }
+  
+  res <- list(rs = rs, ls = ret)
+  
+  return(res)
+  
+}
+
+#' @description Update page numbers in text file
+#' @details Logic is to read in each line of the file, loop through and replace
+#' tokens as needed.  Pages numbers are incremented every time a form feed
+#' is encountered.  Total pages is retrieved from the report pages property.
+#' Total pages is calculated when a page break occurs.
+#' @noRd
+update_page_numbers <- function(rs, lns) {
+  
+  
+  # Set up page variables
+  tpg <- rs$pages
+
+  
+  # Define vectorized function to replace tokens
+  replace_tokens <- Vectorize(function(x, srch, just) {
+    
+    ret <- x
+    
+    # Replace tokens, but keep overall width the same
+    if (grepl(srch, x, fixed = TRUE)) {
+      #print("found it")
+      
+      tmp <- sub("[tpg]", tpg, srch, fixed = TRUE)
+      tmp <- sub("[pg]", pg, tmp, fixed = TRUE)
+      tmp <- pad_any(tmp, nchar(srch), just)
+      ret <- sub(srch, tmp, x, fixed = TRUE)
+    }
+    
+    return(ret)
+  }, USE.NAMES = FALSE)
+  
+  
+  for (pg in seq_along(lns)) {
+  
+    # Call vectorized function on entire page header/footer segment
+    
+    if (token_check(rs$page_header_left)) {
+      for (i in seq_len(length(rs$page_header_left))) {
+        if (token_check(rs$page_header_left[i])) {
+  
+          lns[[pg]] <- replace_tokens(lns[[pg]], rs$page_header_left[i], "left")
+        }
+      }
+    }
+    
+    if (token_check(rs$page_header_right)) {
+      for (i in seq_len(length(rs$page_header_right))) {
+        if (token_check(rs$page_header_right[i])) {
+  
+          lns[[pg]] <- replace_tokens(lns[[pg]], rs$page_header_right[i], "right")
+        }
+      }
+    }
+    
+    if (token_check(rs$page_footer_left)) {
+      for (i in seq_len(length(rs$page_footer_left))) {
+        if (token_check(rs$page_footer_left[i])) {
+          lns[[pg]] <- replace_tokens(lns[[pg]], rs$page_footer_left[i], "left")
+        }
+      }
+    }
+    if (token_check(rs$page_footer_center)) {
+      for (i in seq_len(length(rs$page_footer_center))) {
+        if (token_check(rs$page_footer_center[i])) {
+          lns[[pg]] <- replace_tokens(lns[[pg]], rs$page_footer_center[i], "centre")
+        }
+      }
+    }
+    if (token_check(rs$page_footer_right)) {
+      
+      for (i in seq_len(length(rs$page_footer_right))) {
+        if (token_check( rs$page_footer_right[i])) {
+          lns[[pg]] <- replace_tokens(lns[[pg]], rs$page_footer_right[i], "right")
+        }
+      }
+    }
+    if (!is.null(rs$title_hdr)) {
+      if (token_check(rs$title_hdr$right)) {
+        for (i in seq_len(length(rs$title_hdr$right))) {
+          if (token_check(rs$title_hdr$right[i])) {
+            lns[[pg]] <- replace_tokens(lns[[pg]], rs$title_hdr$right[i], "right")
+          }
+        }
+      }
+    }
+    
+    for (cntnt in rs$content) {
+      if (!is.null(cntnt$object$title_hdr)) { 
+        if (token_check(cntnt$object$title_hdr$right)) {
+          for (i in seq_len(length(cntnt$object$title_hdr$right))) {
+            if (token_check(cntnt$object$title_hdr$right[i])) {
+              lns[[pg]] <- replace_tokens(lns[[pg]], cntnt$object$title_hdr$right[i], "right")
+            }
+          }
+        }
+        
+      }
+    }
+    
+  }
+  
+  
+  return(lns)
+}
+
+
 
 # Write Text Driver Function ----------------------------------------------
 
 
+
 #' @title
 #' Write a text report to the file system
 #'
@@ -140,6 +416,8 @@ paginate_content <- function(rs, ls) {
   return(ret)
 }
 
+
+
 #' @title Write out content
 #' @description This loop writes out pages created in paginate_content
 #' @noRd
@@ -183,7 +461,7 @@ write_content <- function(rs, ls, pt) {
         last_page <- FALSE
       
       
-      f <- file(rs$modified_path, open="a+", encoding = "native.enc")
+      f <- file(rs$modified_path, open="a", encoding = "native.enc")
       
       if (rs$blank_margins)
         writeLines(enc2utf8(blank_margin_top), con = f, useBytes = TRUE)
@@ -208,8 +486,7 @@ write_content <- function(rs, ls, pt) {
       }
       
       if (!is.null(pg)) {
-        tmp <- trimws(format(pg, width = rs$line_size,
-                      justify = get_justify(cont$align)),
+        tmp <- trimws(pad_any(pg, rs$line_size, get_justify(cont$align)),
                       which = "right")
         writeLines(enc2utf8(paste0(blank_margin_left, tmp)), 
                    con = f, useBytes = TRUE)
@@ -356,8 +633,12 @@ write_page_numbers <- function(rs) {
   # Read file into vector
   lns <- readLines(rs$modified_path, encoding = "UTF-8")
   
+
+  # Adjust page count
+  rs$pages <- rs$pages + 1
+  
   # Set up page variables
-  tpg <- rs$pages
+  tpg <- rs$pages 
   pg <- 1
   
   # Define vectorized function to replace tokens
@@ -379,7 +660,7 @@ write_page_numbers <- function(rs) {
       
       tmp <- sub("[tpg]", tpg, srch, fixed = TRUE)
       tmp <- sub("[pg]", pg, tmp, fixed = TRUE)
-      tmp <- format(tmp, width = nchar(srch), justify = just)
+      tmp <- pad_any(tmp, nchar(srch), just)
       ret <- sub(srch, tmp, x, fixed = TRUE)
     }
     
@@ -432,11 +713,13 @@ write_page_numbers <- function(rs) {
     }
   }
   if (!is.null(rs$title_hdr)) {
-    if (token_check(rs$title_hdr$right)) {
-      for (i in seq_len(length(rs$title_hdr$right))) {
-        if (token_check(rs$title_hdr$right[i])) {
-          pg <- 1
-          lns <- replace_tokens(lns, rs$title_hdr$right[i], "right")
+    for (th in rs$title_hdr) {
+      if (token_check(th$right)) {
+        for (i in seq_len(length(th$right))) {
+          if (token_check(th$right[i])) {
+            pg <- 1
+            lns <- replace_tokens(lns, th$right[i], "right")
+          }
         }
       }
     }
@@ -444,15 +727,16 @@ write_page_numbers <- function(rs) {
   
   for (cntnt in rs$content) {
    if (!is.null(cntnt$object$title_hdr)) { 
-     if (token_check(cntnt$object$title_hdr$right)) {
-       for (i in seq_len(length(cntnt$object$title_hdr$right))) {
-         if (token_check(cntnt$object$title_hdr$right[i])) {
-          pg <- 1
-          lns <- replace_tokens(lns, cntnt$object$title_hdr$right[i], "right")
+     for (th in cntnt$object$title_hdr) {
+       if (token_check(th$right)) {
+         for (i in seq_len(length(th$right))) {
+           if (token_check(th$right[i])) {
+            pg <- 1
+            lns <- replace_tokens(lns, th$right[i], "right")
+           }
          }
        }
      }
-     
    }
   }
   
